vviccommon

package module
v0.0.0-...-c2b50a6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 10, 2016 License: Apache-2.0 Imports: 18 Imported by: 0

README

vviccommon

Documentation

Index

Constants

This section is empty.

Variables

var WatermarkImage image.Image

Functions

func Asset

func Asset(name string) ([]byte, error)

Asset loads and returns the asset for the given name. It returns an error if the asset could not be found or could not be loaded.

func AssetDir

func AssetDir(name string) ([]string, error)

AssetDir returns the file names below a certain directory embedded in the file by go-bindata. For example if you run go-bindata on data/... and data contains the following hierarchy:

data/
  foo.txt
  img/
    a.png
    b.png

then AssetDir("data") would return []string{"foo.txt", "img"} AssetDir("data/img") would return []string{"a.png", "b.png"} AssetDir("foo.txt") and AssetDir("notexist") would return an error AssetDir("") will return []string{"data"}.

func AssetInfo

func AssetInfo(name string) (os.FileInfo, error)

AssetInfo loads and returns the asset info for the given name. It returns an error if the asset could not be found or could not be loaded.

func AssetNames

func AssetNames() []string

AssetNames returns the names of the assets.

func CompositeLogo(r io.Reader, w io.Writer) (err error)

func CompositeWatermark

func CompositeWatermark(r io.Reader, w io.Writer) (err error)

func MustAsset

func MustAsset(name string) []byte

MustAsset is like Asset but panics when Asset would return an error. It simplifies safe initialization of global variables.

func RestoreAsset

func RestoreAsset(dir, name string) error

RestoreAsset restores an asset under the given directory

func RestoreAssets

func RestoreAssets(dir, name string) error

RestoreAssets restores an asset under the given directory recursively

func ScaleForMobile

func ScaleForMobile(r io.Reader, w io.Writer) (err error)

func ScaleImageToJpeg

func ScaleImageToJpeg(width uint, quality int, r io.Reader, w io.Writer) (err error)

func ScaleTo800x800

func ScaleTo800x800(r io.Reader, w io.Writer) (err error)

func ShuffleTitle

func ShuffleTitle(in string) (out string, err error)

func TidyTitle

func TidyTitle(in string) string

Types

type Err

type Err struct {
	Pkg  string
	Info string
	Prev error
}

func (*Err) Error

func (e *Err) Error() string

Jump to